@@ -1,7 +1,7 @@
 package HTTP::Tiny::Retry;
 
 our $DATE = '2019-04-10'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,20 @@ use Log::ger;
 
 use parent 'HTTP::Tiny';
 
+sub new {
+    my ($class, %attrs) = @_;
+
+    my %our_attrs;
+    for ("retries", "retry_delay") {
+        $our_attrs{$_} = delete $attrs{$_}
+            if exists $attrs{$_};
+    }
+
+    my $self = $class->SUPER::new(%attrs);
+    $self->{$_} = $our_attrs{$_} for keys %our_attrs;
+    $self;
+}
+
 sub request {
     my ($self, $method, $url, $options) = @_;
 
@@ -50,7 +64,7 @@ HTTP::Tiny::Retry - Retry failed HTTP::Tiny requests
 
 =head1 VERSION
 
-This document describes version 0.002 of HTTP::Tiny::Retry (from Perl distribution HTTP-Tiny-Retry), released on 2019-04-10.
+This document describes version 0.003 of HTTP::Tiny::Retry (from Perl distribution HTTP-Tiny-Retry), released on 2019-04-10.
 
 =head1 SYNOPSIS
 
